==> igniteui-react-layouts-18.6.1.tgz: package/esm5/lib/igr-tool-action-button.js <==
import { __extends } from "tslib";
import { ToolActionButtonDisplayType_$type } from "./ToolActionButtonDisplayType";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionButton } from "./ToolActionButton";
import { ensureEnum } from "igniteui-react-core";
var IgrToolActionButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionButton, _super);
    function IgrToolActionButton(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionButton.prototype.createImplementation = function () {
        return new ToolActionButton();
    };
    Object.defineProperty(IgrToolActionButton.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionButton.prototype, "displayType", {
        /**
         * Gets or sets the display type for the button.
        */
        get: function () {
            return this.i.f7;
        },
        set: function (v) {
            this.i.f7 = ensureEnum(ToolActionButtonDisplayType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionButton.prototype, "cornerRadius", {
        /**
         * Gets or sets the button corner radius.
        */
        get: function () {
            return this.i.gc;
        },
        set: function (v) {
            this.i.gc = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionButton;
}(IgrToolAction));
export { IgrToolActionButton };

==> igniteui-react-layouts-18.7.3.tgz: package/esm5/lib/igr-tool-action-button.js <==
import { __extends } from "tslib";
import { ToolActionButtonDisplayType_$type } from "./ToolActionButtonDisplayType";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionButton } from "./ToolActionButton";
import { ensureEnum } from "igniteui-react-core";
var IgrToolActionButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionButton, _super);
    function IgrToolActionButton(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionButton.prototype.createImplementation = function () {
        return new ToolActionButton();
    };
    Object.defineProperty(IgrToolActionButton.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionButton.prototype, "displayType", {
        /**
         * Gets or sets the display type for the button.
        */
        get: function () {
            return this.i.hb;
        },
        set: function (v) {
            this.i.hb = ensureEnum(ToolActionButtonDisplayType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionButton.prototype, "cornerRadius", {
        /**
         * Gets or sets the button corner radius.
        */
        get: function () {
            return this.i.hg;
        },
        set: function (v) {
            this.i.hg = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionButton;
}(IgrToolAction));
export { IgrToolActionButton };
